@@ -207,7 +207,7 @@ def run(runner, job, docker):
         trace_checkoutput(trace, ["git", "clone", git["repo_url"], build_dir], cwd=tempdir)
 
         # checkout the ref to build
-        trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_BUILD_REF")], cwd=build_dir_abs)
+        trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_COMMIT_REF")], cwd=build_dir_abs)
 
         end_log_section(trace, "git")
 
